==> qt-creator-opensource-src-3.0.1.zip: qt-creator-opensource-src-3.0.1/src/plugins/android/javaparser.h <==
/**************************************************************************
**
** Copyright (c) 2014 BogDan Vatra <bog_dan_ro@yahoo.com>
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef JAVAPARSER_H
#define JAVAPARSER_H

#include <projectexplorer/ioutputparser.h>

namespace Android {
namespace Internal {

class JavaParser : public ProjectExplorer::IOutputParser
{
    Q_OBJECT

public:
    JavaParser();
    void stdOutput(const QString &line);
    void stdError(const QString &line);
    void setProjectFileList(const QStringList &fileList);

private:
    void parse(const QString &line);

    QRegExp m_javaRegExp;
    QStringList m_fileList;
};

} // namespace Internal
} // namespace Android

#endif // JAVAPARSER_H

==> qt-creator-opensource-src-3.1.1.zip: qt-creator-opensource-src-3.1.1/src/plugins/android/javaparser.h <==
/**************************************************************************
**
** Copyright (c) 2014 BogDan Vatra <bog_dan_ro@yahoo.com>
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef JAVAPARSER_H
#define JAVAPARSER_H

#include <projectexplorer/ioutputparser.h>
#include <utils/fileutils.h>

namespace Android {
namespace Internal {

class JavaParser : public ProjectExplorer::IOutputParser
{
    Q_OBJECT

public:
    JavaParser();
    void stdOutput(const QString &line);
    void stdError(const QString &line);
    void setProjectFileList(const QStringList &fileList);

    void setBuildDirectory(const Utils::FileName &buildDirectory);
    void setSourceDirectory(const Utils::FileName &sourceDirectory);

private:
    void parse(const QString &line);

    QRegExp m_javaRegExp;
    QStringList m_fileList;
    Utils::FileName m_sourceDirectory;
    Utils::FileName m_buildDirectory;
};

} // namespace Internal
} // namespace Android

#endif // JAVAPARSER_H
